#! /bin/sh
#
# skeleton	example file to build /etc/init.d/ scripts.
#		This file should be used to construct scripts for /etc/init.d.
#
#		Written by Miquel van Smoorenburg <miquels@cistron.nl>.
#		Modified for Debian 
#		by Ian Murdock <imurdock@gnu.ai.mit.edu>.
#
# Version:	@(#)skeleton  1.9  26-Feb-2001  miquels@cistron.nl
#

### BEGIN INIT INFO
# Provides:          osaas-server
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Should-Start:      $named
# Should-Stop:       $named
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start OSAAS-Server.
# Description:       Start the OSAAS-Server to log OWS-Requests in combination with deegree-owsproxy.
### END INIT INFO

PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
DAEMON=/opt/gispatcher/osaas-server/server/startosaas.py
OSAAS_RUN=false
NAME=osaas
DESC=OSAAS-Server

test -x $DAEMON || exit 0

# Include osaas defaults if available
if [ -f /etc/default/osaas-server ] ; then
	. /etc/default/osaas-server
fi

set -e

case "$1" in
  start)
        if "$OSAAS_RUN"; then
	    echo -n "Starting $DESC: "
	    start-stop-daemon --start -c $OSAAS_USER:$OSAAS_GROUP --quiet -b --pidfile $OSAAS_PID  \
	    	--exec $DAEMON -- --config-file=$CONFIG_FILE --pid-file=$OSAAS_PID
	    echo "$NAME."
        else
            echo  "Please configure OSAAS and set the value OSAAS_RUN in /etc/default/osaas-server appropriate."
            exit 0
        fi
	;;
  stop)
        if "$OSAAS_RUN"; then
	    echo -n "Stopping $DESC: "
	    kill -TERM `cat $OSAAS_PID`
	    echo "$NAME."
        else
            echo  "Please configure OSAAS and set the value OSAAS_RUN in /etc/default/osaas-server appropriate."
            exit 0
        fi
	;;
  force-reload)
	#
	#	If the "reload" option is implemented, move the "force-reload"
	#	option to the "reload" entry above. If not, "force-reload" is
	#	just the same as "restart" except that it does nothing if the
	#   daemon isn't already running.
	# check wether $DAEMON is running. If so, restart
	start-stop-daemon --stop -c $OSAAS_USER:$OSAAS_GROUP --test --quiet --pidfile \
		$OSAAS_PID --exec $DAEMON -- --config-file=$CONFIG_FILE --pid-file=$OSAAS_PID\
	&& $0 restart \
	|| exit 0
	;;
  restart)
    echo -n "Restarting $DESC: "  
	kill -TERM `cat $OSAAS_PID`
	sleep 1
	start-stop-daemon --start -c $OSAAS_USER:$OSAAS_GROUP --quiet -b --pidfile \
		$OSAAS_PID --exec $DAEMON -- --config-file=$CONFIG_FILE --pid-file=$OSAAS_PID
	echo "$NAME."
	;;
  *)
	N=/etc/init.d/$NAME
	echo "Usage: $N {start|stop|restart|force-reload}" >&2
	exit 1
	;;
esac

exit 0
