# Copyright (C) 2007 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file GPL.txt coming with the software for details.

"""Support code for the test cases"""

import os

def create_temp_dir():
    """Create a temporary directory for the test-suite and return its name.

    The temporary directory is always called temp and is created in the
    directory where the support module is located.

    If the temp directory already exists, just return the name.
    """
    name = os.path.abspath(os.path.join(os.path.dirname(__file__), "temp"))

    # if the directory already exists, we're done
    if os.path.isdir(name):
        return name

    # create the directory
    os.mkdir(name)
    return name


class FileTestMixin:

    """Mixin class for tests that use files in the temporary directory
    """

    def temp_file_name(self, basename, remove=False):
        """Return the full name of the file named basename in the temp. dir.
        If the remove parameter is true, the file is removed if already exists.
        """
        filename = os.path.join(create_temp_dir(), basename)
        if remove and os.path.exists(filename):
            os.remove(filename)
        return filename

    def create_temp_file(self, basename, contents, mode = None):
        """Create a file in the temp directory"""
        filename = self.temp_file_name(basename)
        file = open(filename, "w")
        file.write(contents)
        file.close()
        if mode is not None:
            os.chmod(filename, mode)
        return filename


class AttributeTestMixin:

    def check_attributes(self, obj, **attrs):
        for key, value in attrs.items():
            self.assertEquals(getattr(obj, key), value)
